@@ -2,7 +2,6 @@
 # Copyright (C) 2019--2022  Matthew P. Humphreys  (GNU GPLv3)
 """Set default values."""
 
-
 dic = 0  # micromol / kg-solution
 dpi = 300  # resolution of figures
 fCO2_air = 450  # for DIC loss modelling, µatm
@@ -19,7 +18,7 @@ opt_total_borate = 1  # for PyCO2SYS
 pH_range = (3, 4)  # pH range to use for solving alkalinity
 pressure = 0  # in-water pressure in dbar
 read_dat_method = "genfromtxt"
-salinity = 35  # practical
+salinity = 35.0  # practical (dimensionless)
 split_pH = 5.5  # for DIC loss modelling
 titrant = "HCl"
 titrant_amount_unit = "ml"
